#!/bin/sh
set -ev

test $DARCS || DARCS=$PWD/../darcs

rm -rf temp1
mkdir temp1
cd temp1
$DARCS init
touch foo
$DARCS add foo
$DARCS record -a -m add_foo -A x
rm foo
$DARCS whatsnew
cd ..
rm -rf temp1

